@@ -5,13 +5,13 @@
 """
 
 __author__ = 'Ryan Fisher <ryan.fisher@ligo.org>'
-__version__ = 'dqsegdb-release-1-2-2'
-__date__ = '2015-08-20 01:01:22 +0000'
+__version__ = 'dqsegdb-release-1-3-2'
+__date__ = '2016-06-23 20:23:17 +0000'
 
-version = 'dqsegdb-release-1-2-2'
-git_id = 'aaf2baa9c7e8c6b05f56264b1f3b8b9e5bd0d171'
-git_branch = None
-git_tag = 'dqsegdb-release-1-2-2'
+version = 'dqsegdb-release-1-3-2'
+git_id = 'afb8446a516ef79fa3ec0f36af5366bc135863ce'
+git_branch = 'dqsegdb-release-branch-1-3'
+git_tag = 'dqsegdb-release-1-3-2'
 git_author = 'Ryan Fisher <ryan.fisher@ligo.org>'
 git_committer = 'Ryan Fisher <ryan.fisher@ligo.org>'
 git_status = 'UNCLEAN: Modified working tree'
